from .base import BaseCFObject


class Condition(BaseCFObject):
    top_level_key = "Conditions"
